@@ -14,8 +14,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_1(self):
         model = WeightedTomitasGrammars.get_automaton_1()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -23,8 +23,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_2(self):
         model = WeightedTomitasGrammars.get_automaton_2()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model, PDFAComparator())
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -32,8 +32,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_3(self):
         model = WeightedTomitasGrammars.get_automaton_3()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -41,8 +41,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_4(self):
         model = WeightedTomitasGrammars.get_automaton_4()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -50,8 +50,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_5(self):
         model = WeightedTomitasGrammars.get_automaton_5()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -59,8 +59,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_6(self):
         model = WeightedTomitasGrammars.get_automaton_6()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
@@ -68,8 +68,8 @@ class TestPDFALStarColLearner(unittest.TestCase):
 
     def test_tomitas_7(self):
         model = WeightedTomitasGrammars.get_automaton_7()
-        teacher = PDFATeacher(model, 0, PDFAComparator())
-        result = self.learner.learn(teacher)
+        teacher = PDFATeacher(model, PDFAComparator())
+        result = self.learner.learn(teacher, tolerance = 0)
         extracted_model = result.model
         self.assertEqual(model, extracted_model)
         self.assertTrue(result.info['last_token_weight_queries_count']>0)        
